﻿// This example uses gpib card zero and chamber controller gpib address of 10

using System;
using System.Threading;
using NationalInstruments.VisaNS;

namespace CSharp_GPIB_chamber_io_visa
{
  class Program
  {
    static private MessageBasedSession mbSession;

    static void Main(string[] args)
    {
      // VISA resource string:
      string strGpibVisaResoureString = "GPIB0::10::INSTR"; // Chamber controller gpib address set to 10

      mbSession = (MessageBasedSession)ResourceManager.GetLocalManager().Open(strGpibVisaResoureString);

      // get chamber identification
      string strValue = mbSession.Query("*idn?\r");
      Console.WriteLine("Value read from chamber controller=" + strValue);

      // Note:  ALWAYS read after a write even if not needing a return value
      strValue = mbSession.Query("RUNM\r"); // run manual
      Console.WriteLine("Put chamber in Run Manual mode");

      for (int nLoop = 0; nLoop < 10; nLoop++)
      {
        Thread.Sleep(1000);
        strValue = mbSession.Query("SETP1," + (nLoop + 25) + "\r"); // write setpoint
        Console.WriteLine("Write new setpoint =" + (nLoop + 25));

        strValue = mbSession.Query("PVAR1?\r"); // query process variable one (temperature)
        Console.WriteLine("Process variable 1 (temperature) =" + strValue);

        strValue = mbSession.Query("SETP1?\r"); // get current setpoint
        Console.WriteLine("Temperature Setpoint =" + strValue);
      }

      // Note:  ALWAYS read after a write even if not needing a return value
      strValue = mbSession.Query("STOP\r"); // stop chamber
      Console.WriteLine("Chamber stopped");

      Console.WriteLine("Press any key...");
      Console.ReadKey();
    }
  }
}
